<?php
// @codingStandardsIgnoreFile
// @codeCoverageIgnoreStart
// this is an autogenerated file - do not edit
spl_autoload_register(
    function($class) {
        static $classes = null;
        if ($classes === null) {
            $classes = array(
                'theseer\\directoryscanner\\directoryscanner' => '/directoryscanner.php',
                'theseer\\directoryscanner\\exception' => '/directoryscanner.php',
                'theseer\\directoryscanner\\filesonlyfilteriterator' => '/filesonlyfilter.php',
                'theseer\\directoryscanner\\includeexcludefilteriterator' => '/includeexcludefilter.php',
                'theseer\\directoryscanner\\phpfilteriterator' => '/phpfilter.php'
            );
        }
        $cn = strtolower($class);
        if (isset($classes[$cn])) {
            require __DIR__ . $classes[$cn];
        }
    }
);
// @codeCoverageIgnoreEnd
